package com.ruoyi.common.utils.wechat;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.domain.entity.AccessTokenVo;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.http.HttpUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Objects;
import java.util.concurrent.TimeUnit;

@Component
public class WechatUtils {

    private static final Logger logger = LoggerFactory.getLogger(WechatUtils.class);

    /**
     * 微信小程序AppID
     */
    @Value("${wx.mpAppId}")
    private String appId;
    /**
     * 微信小程序AppSecret
     */
    @Value("${wx.mpSecret}")
    private String appSecret;

    @Autowired
    private RedisCache redisCache;

    /**
     * 获取access_token
     * @return
     */
    public String getMpAccessToken() {
        String accessToken = redisCache.getCacheObject(WechatKeys.MP_ACCESS_TOKEN_REDIS_KEY);
        if (StringUtils.isBlank(accessToken)) {
            String accessTokenUrl = String.format(WechatKeys.ACCESS_TOKEN_URL, appId, appSecret);
            String result = HttpUtils.sendGet(accessTokenUrl);
            JSONObject jsonObject = JSONObject.parseObject(result);
            AccessTokenVo accessTokenVo = JSONObject.toJavaObject(jsonObject, AccessTokenVo.class);
            if (Objects.nonNull(accessTokenVo) && StringUtils.isNotBlank(accessTokenVo.getAccessToken())) {
                accessToken = accessTokenVo.getAccessToken();
                redisCache.setCacheObject(WechatKeys.MP_ACCESS_TOKEN_REDIS_KEY, accessTokenVo.getAccessToken(), accessTokenVo.getExpiresIn(), TimeUnit.SECONDS);
            }
        }
        return accessToken;
    }




}
