package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.system.domain.TPatientHospitalDoctor;

import com.ruoyi.system.domain.TPatient;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.PlatformDayPlanResp;
import com.ruoyi.system.domain.resp.TRecordResp;
import com.ruoyi.system.domain.resp.WeekMonthPersonCountResp;
import com.ruoyi.system.domain.resp.WeekMonthTimeResp;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 诊断记录信息Mapper接口
 *
 * @author ruoyi
 * @date 2022-08-03
 */
@Mapper
public interface TRecordMapper
{
    /**
     * --------------------------工作台相关接口------------------------------------------
     */
    /**
     * 设备统计各个个数查询
     * @param hospitalId
     * @param doctorId
     * @return
     */
    int selectEquCount(@Param("hospitalId") Long hospitalId,
                       @Param("doctorId")Long doctorId,
                       @Param("status")String status,
                       @Param("month")Long month,
                       @Param("week")Long week,
                       @Param("day")Long day);

    /**
     * 今日就诊计划
     * @param hospitalId
     * @param doctorId
     * @return
     */
    List<PlatformDayPlanResp> dayPlan(@Param("hospitalId") Long hospitalId,
                                      @Param("doctorId")Long doctorId);

    /**
     * 就诊人数统计 1-周 2-月
     * @param hospitalId
     * @param doctorId
     * @param weekMonth
     * @return
     */
    List<WeekMonthPersonCountResp> weekMonthPersonCount(@Param("hospitalId")Long hospitalId,
                                                        @Param("doctorId")Long doctorId,
                                                        @Param("weekMonth")Long weekMonth);


    /**
     * 年龄分布
     * @param hospitalId
     * @param doctorId
     * @return
     */
    List<TPatient> ageCount(@Param("hospitalId")Long hospitalId,
                            @Param("doctorId")Long doctorId);

    /**
     * 就诊时段统计
     * @param hospitalId
     * @param doctorId
     * @param weekMonth
     * @return
     */
    List<WeekMonthTimeResp> weekMonthTimeCount(@Param("hospitalId")Long hospitalId,
                                               @Param("doctorId")Long doctorId,
                                               @Param("weekMonth")Long weekMonth);

    /**
     * --------------------------工作台相关接口------------------------------------------
     */
    /**
     * 此医生最近一次就诊时间
     * @param tRecord
     * @return
     */
    public List<TRecord> selectTRecordDoctorFirst(TRecord tRecord);


    /**
     * 查询诊断记录信息
     *
     * @param id 诊断记录信息主键
     * @return 诊断记录信息
     */
    public TRecord selectTRecordById(Long id);

    /**
     * 查询诊断记录信息列表
     *
     * @param tRecord 诊断记录信息
     * @return 诊断记录信息集合
     */
    public List<TRecord> selectTRecordList(TRecord tRecord);

    /**
     * 新增诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    public int insertTRecord(TRecord tRecord);

    /**
     * 修改诊断记录信息
     *
     * @param tRecord 诊断记录信息
     * @return 结果
     */
    public int updateTRecord(TRecord tRecord);

    /**
     * 删除诊断记录信息
     *
     * @param id 诊断记录信息主键
     * @return 结果
     */
    public int deleteTRecordById(Long id);

    /**
     * 批量删除诊断记录信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTRecordByIds(Long[] ids);

    List<TRecordResp> selectTRecordListWithoutResult(TRecordResultReq tRecord);

    TRecordResp selectById(Long id);

    /**
     * 通过病人医院医生id查询记录列表
     *
     * @param tPatientHospitalDoctor t病人医院医生
     * @return {@code List<TRecord>}
     */
    public List<TRecordResp> queryRecordListByPHDids(TPatientHospitalDoctor tPatientHospitalDoctor);
}
